#!/bin/bash

usage()
{
	echo -e "Usage: $0 [-h] <custom_liveburner.ipk>
\t-h: this usage
\tcustom_liveburner.ipk: custom liveburner to extract elements from"
}

if [ $# -lt 1 ]
then
	usage
	exit 1
fi

while getopts "h" opt; do
	case "$opt" in
	h)
		usage
		exit 1
		;;
	*)
		usage
		exit 1
		;;
	esac
done

LIVEBURNER_PATH=`realpath -L "$1"`
LIVEBURNER_FILENAME=`basename "${LIVEBURNER_PATH}"`
LIVEBURNER_PATH=`dirname "${LIVEBURNER_PATH}"`
LIVEBURNER_ELEMS_PATH="${LIVEBURNER_PATH}/${LIVEBURNER_FILENAME%.*}"
WORKING_DIR=`pwd`

. functions

#########################
# MAIN
#########################

ipk_extract "$1" "${WORKSPACE}"
itb_extract "${ITB_WORKSPACE}/linux.itb" "${ITB_WORKSPACE}"
initrd_extract "${INITRD_DIR}/ramdisk@1" "${INITRD_DIR}"

echo -e "\n== Extracting elements ==\n"
rm -fR "${LIVEBURNER_ELEMS_PATH}"
mkdir -p "${LIVEBURNER_ELEMS_PATH}"
for elem in $(ls "${INITRD_DIR}/initrd/burner/")
do
	cp -f "${INITRD_DIR}/initrd/burner/${elem}" "${LIVEBURNER_ELEMS_PATH}/"
	echo "File ${elem} extracted"
done

if [ -f "${WORKSPACE}/ipk/control/preinst" ];
then
	cp -f "${WORKSPACE}/ipk/control/preinst" "${LIVEBURNER_ELEMS_PATH}/"
	echo "File preinst extracted"
fi

echo -e "\nAll elements are extracted in ${LIVEBURNER_ELEMS_PATH} directory \n"
echo "== Extraction finished =="

rm -rf "${WORKSPACE}"
