#!/bin/bash

OPTIND=1

# Versions
SCRIPT_VERSION="v4.1.0-0-g35f153a"
SPFTOCPF_VERSION="4.1-beta1-16-g3eaed93"
SPFTOCPF_KLKGW_VERSION="4.1.1-0-gf8eb99e"

# Comments on the final custom liveburner
IPK_COMMENT=""

usage()
{
	echo -e "Usage: $0 [-v] [-m <comment>][-h] <liveburner.ipk> <file 1>...<file n>
\t-v: Show versions
\t-m: Add comment in CONTROL file
\t-h: this usage
\tliveburner.ipk: liveburner file to be updated with ipk
\tfile X: list of ipk and/or scripts to be added to the liveburner"
}

get_version()
{
	echo "Script version: ${SCRIPT_VERSION}"
	echo "spftocpf binaries version:"
	echo -e "\tklk_lpbs and klk_wifc architectures (KerOS version <= 4.0): ${SPFTOCPF_VERSION}"
	echo -e "\tklkgw architecture (KerOS version >= 4.1): ${SPFTOCPF_KLKGW_VERSION}"
}

if [ $# -lt 1 ]
then
	usage
	exit 1
fi

while getopts "hvm:" opt; do
	case "$opt" in
	h)
		usage
		exit 1
		;;
	v)
		get_version
		exit 1
		;;
	m)
		IPK_COMMENT="${OPTARG}"
		;;
	*)
		usage
		exit 1
		;;
	esac
done

[ ! -z "${IPK_COMMENT}" ] && shift 2

UPDATELIVEBURNERLOG=/tmp/updateliveburner.log
exec 3>&1 4>&2 > ${UPDATELIVEBURNERLOG}

LIVEBURNER_PATH=`realpath -L "$1"`
LIVEBURNER_FILENAME=`basename "${LIVEBURNER_PATH}"`
LIVEBURNER_PATH=`dirname "${LIVEBURNER_PATH}"`
WORKING_DIR=`pwd`

. functions

#########################
# MAIN
#########################

detect_liveburner_machine
ipk_extract "$1" "${WORKSPACE}"
itb_extract "${ITB_WORKSPACE}/linux.itb" "${ITB_WORKSPACE}"
initrd_extract "${INITRD_DIR}/ramdisk@1" "${INITRD_DIR}"

INITRD_SIZE=`du -sb ${INITRD_DIR}/initrd | sed 's/\s.*$//'`
CUSTOM_IPK_MAX_SIZE=$((INITRD_MAX_SIZE - INITRD_SIZE))
CUSTOM_IPK_SIZE=0

cd "${WORKING_DIR}"
[ ! -z "${IPK_COMMENT}" ] && echo "   Burner information: ${IPK_COMMENT}" >> "${WORKSPACE}/ipk/control/control"
echo "   Files added:" >> "${WORKSPACE}/ipk/control/control"
deploy_spftocpf_bin_in_initrd
shift $((OPTIND))
while [ $# != 0 ]
do
	if [ -f "$1" ]
	then
		FILESIZE=`stat -c%s "$1"`
		CUSTOM_IPK_SIZE=$((CUSTOM_IPK_SIZE + FILESIZE))
		FILENAME=$(basename -- "$1")
		if [ ${CUSTOM_IPK_SIZE} -gt ${CUSTOM_IPK_MAX_SIZE} ]
		then
			echo "Error : custom IPK size exceed max size (${CUSTOM_IPK_MAX_SIZE} bytes) with file $1"
			rm -rf ${WORKSPACE}
			exit 1
		fi

		# preinst script is specific and must be installed in liveburner
		if [ "${FILENAME}" = "preinst" ]
		then
			cp "$1" "${IPK_WORKSPACE}/control/"
			chmod 777 "${IPK_WORKSPACE}/control/${FILENAME}"
		else
			cp "$1" "${INITRD_DIR}/initrd/burner/"
			chmod 777 "${INITRD_DIR}/initrd/burner/${FILENAME}"
		fi

		echo "      ${FILENAME}" >> "${WORKSPACE}/ipk/control/control"
		shift
	else
		echo "Error : File $1 not found"
		rm -rf ${WORKSPACE}
		exit 1
	fi
done

initrd_build "${INITRD_DIR}" "${INITRD_DIR}/ramdisk@1"
itb_build "${ITB_WORKSPACE}" "${ITB_WORKSPACE}/linux.itb" "${ITB_WORKSPACE}/linux.itb-new"
rm -f "${ITB_WORKSPACE}/linux.itb"
mv "${ITB_WORKSPACE}/linux.itb-new" "${ITB_WORKSPACE}/linux.itb"
ipk_build "${WORKSPACE}" "${LIVEBURNER_PATH}/custom-${LIVEBURNER_FILENAME}"

rm -rf "${WORKSPACE}"

exec echo "Liveburner custom-${LIVEBURNER_FILENAME} created" 1>&3
